==> jc-1.4.0.tar.gz: java/awt/geom/QuadCurve2D__241.h <==
// final class java.awt.geom.QuadCurve2D$1

// class file dependencies
// @dep_class b42414fc326f846b java_awt_geom_QuadCurve2D__241
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_geom_QuadCurve2D__241_H_
#define _JC_java_awt_geom_QuadCurve2D__241_H_

// Forward structure declarations
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_awt_geom_QuadCurve2D$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_QuadCurve2D__241$sub_refs	_jc_java_awt_geom_QuadCurve2D__241$sub_refs;
typedef struct _jc_java_awt_geom_QuadCurve2D__241$sub_nonrefs	_jc_java_awt_geom_QuadCurve2D__241$sub_nonrefs;
typedef struct _jc_java_awt_geom_QuadCurve2D__241$refs	_jc_java_awt_geom_QuadCurve2D__241$refs;
typedef struct _jc_java_awt_geom_QuadCurve2D__241$nonrefs	_jc_java_awt_geom_QuadCurve2D__241$nonrefs;
typedef struct _jc_java_awt_geom_QuadCurve2D__241$object	_jc_java_awt_geom_QuadCurve2D__241$object;

typedef const struct _jc_java_awt_geom_QuadCurve2D__241$vmethods	_jc_java_awt_geom_QuadCurve2D__241$vmethods;
typedef const struct _jc_java_awt_geom_QuadCurve2D__241$vtable	_jc_java_awt_geom_QuadCurve2D__241$vtable;
typedef const struct _jc_java_awt_geom_QuadCurve2D__241$vtype	_jc_java_awt_geom_QuadCurve2D__241$vtype;

// Constructors
extern void _jc_java_awt_geom_QuadCurve2D__241$method$_init$e9b19ce6ad0d12eb(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *, struct _jc_java_awt_geom_QuadCurve2D$object *, struct _jc_java_awt_geom_AffineTransform$object *);

// Virtual methods
extern jint _jc_java_awt_geom_QuadCurve2D__241$method$currentSegment$6f11896d92c6b52a(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *, struct _jc_double_array *);
extern jint _jc_java_awt_geom_QuadCurve2D__241$method$currentSegment$cecac40191e782ca(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *, struct _jc_float_array *);
extern jint _jc_java_awt_geom_QuadCurve2D__241$method$getWindingRule$91001ac946a586fb(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *);
extern jboolean _jc_java_awt_geom_QuadCurve2D__241$method$isDone$5a7c3805879a074d(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *);
extern void _jc_java_awt_geom_QuadCurve2D__241$method$next$08839245f4046cfe(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *);
extern void _jc_java_awt_geom_QuadCurve2D__241$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_QuadCurve2D__241$method_info$currentSegment$6f11896d92c6b52a;
extern _jc_method _jc_java_awt_geom_QuadCurve2D__241$method_info$currentSegment$cecac40191e782ca;
extern _jc_method _jc_java_awt_geom_QuadCurve2D__241$method_info$getWindingRule$91001ac946a586fb;
extern _jc_method _jc_java_awt_geom_QuadCurve2D__241$method_info$isDone$5a7c3805879a074d;
extern _jc_method _jc_java_awt_geom_QuadCurve2D__241$method_info$next$08839245f4046cfe;
extern _jc_method _jc_java_awt_geom_QuadCurve2D__241$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_awt_geom_QuadCurve2D__241$vmethods {
	jint	(*currentSegment$6f11896d92c6b52a)(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *, struct _jc_double_array *);
	jint	(*currentSegment$cecac40191e782ca)(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *, struct _jc_float_array *);
	jint	(*getWindingRule$91001ac946a586fb)(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *);
	jboolean	(*isDone$5a7c3805879a074d)(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *);
	void	(*next$08839245f4046cfe)(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *);
};

// Vtable
struct _jc_java_awt_geom_QuadCurve2D__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_QuadCurve2D__241$vmethods	java_awt_geom_QuadCurve2D__241;
};

// Vtype
struct _jc_java_awt_geom_QuadCurve2D__241$vtype {
	_jc_type			type;
	_jc_java_awt_geom_QuadCurve2D__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_QuadCurve2D__241$sub_refs {
	struct _jc_java_awt_geom_QuadCurve2D$object	*this;
	struct _jc_java_awt_geom_AffineTransform$object	*val__24at;
};

// Reference instance fields (object)
struct _jc_java_awt_geom_QuadCurve2D__241$refs {
    _jc_java_awt_geom_QuadCurve2D__241$sub_refs	java_awt_geom_QuadCurve2D__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_QuadCurve2D__241$sub_nonrefs {
	jint	current;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_QuadCurve2D__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_QuadCurve2D__241$sub_nonrefs	java_awt_geom_QuadCurve2D__241;
};

// Object instance structure
struct _jc_java_awt_geom_QuadCurve2D__241$object {
	_jc_java_awt_geom_QuadCurve2D__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_QuadCurve2D__241$vtype	*vtype;
	_jc_java_awt_geom_QuadCurve2D__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_QuadCurve2D__241$vtype _jc_java_awt_geom_QuadCurve2D__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_QuadCurve2D__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_QuadCurve2D__241$class_object;

#endif	/* _JC_java_awt_geom_QuadCurve2D__241_H_ */

==> jc-1.4.6.tar.gz: java/awt/geom/QuadCurve2D__241.h <==
// final class java.awt.geom.QuadCurve2D$1

// class file dependencies
// @dep_class b42414fc326f846b java_awt_geom_QuadCurve2D__241
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_geom_QuadCurve2D__241_H_
#define _JC_java_awt_geom_QuadCurve2D__241_H_

// Forward structure declarations
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_awt_geom_QuadCurve2D$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_QuadCurve2D__241$sub_refs	_jc_java_awt_geom_QuadCurve2D__241$sub_refs;
typedef struct _jc_java_awt_geom_QuadCurve2D__241$sub_nonrefs	_jc_java_awt_geom_QuadCurve2D__241$sub_nonrefs;
typedef struct _jc_java_awt_geom_QuadCurve2D__241$refs	_jc_java_awt_geom_QuadCurve2D__241$refs;
typedef struct _jc_java_awt_geom_QuadCurve2D__241$nonrefs	_jc_java_awt_geom_QuadCurve2D__241$nonrefs;
typedef struct _jc_java_awt_geom_QuadCurve2D__241$object	_jc_java_awt_geom_QuadCurve2D__241$object;

typedef const struct _jc_java_awt_geom_QuadCurve2D__241$vmethods	_jc_java_awt_geom_QuadCurve2D__241$vmethods;
typedef const struct _jc_java_awt_geom_QuadCurve2D__241$vtable	_jc_java_awt_geom_QuadCurve2D__241$vtable;
typedef const struct _jc_java_awt_geom_QuadCurve2D__241$vtype	_jc_java_awt_geom_QuadCurve2D__241$vtype;

// Constructors
extern void _jc_java_awt_geom_QuadCurve2D__241$method$_init$e9b19ce6ad0d12eb(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *, struct _jc_java_awt_geom_QuadCurve2D$object *, struct _jc_java_awt_geom_AffineTransform$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_awt_geom_QuadCurve2D__241$method$currentSegment$6f11896d92c6b52a(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *, struct _jc_double_array *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_geom_QuadCurve2D__241$method$currentSegment$cecac40191e782ca(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_geom_QuadCurve2D__241$method$getWindingRule$91001ac946a586fb(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_geom_QuadCurve2D__241$method$isDone$5a7c3805879a074d(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_QuadCurve2D__241$method$next$08839245f4046cfe(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_QuadCurve2D__241$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_QuadCurve2D__241$method_info$currentSegment$6f11896d92c6b52a;
extern _jc_method _jc_java_awt_geom_QuadCurve2D__241$method_info$currentSegment$cecac40191e782ca;
extern _jc_method _jc_java_awt_geom_QuadCurve2D__241$method_info$getWindingRule$91001ac946a586fb;
extern _jc_method _jc_java_awt_geom_QuadCurve2D__241$method_info$isDone$5a7c3805879a074d;
extern _jc_method _jc_java_awt_geom_QuadCurve2D__241$method_info$next$08839245f4046cfe;
extern _jc_method _jc_java_awt_geom_QuadCurve2D__241$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_awt_geom_QuadCurve2D__241$vmethods {
	jint	(*currentSegment$6f11896d92c6b52a)(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *, struct _jc_double_array *) _JC_JCNI_ATTR;
	jint	(*currentSegment$cecac40191e782ca)(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	jint	(*getWindingRule$91001ac946a586fb)(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *) _JC_JCNI_ATTR;
	jboolean	(*isDone$5a7c3805879a074d)(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *) _JC_JCNI_ATTR;
	void	(*next$08839245f4046cfe)(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_awt_geom_QuadCurve2D__241$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_geom_QuadCurve2D__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_QuadCurve2D__241$vmethods	java_awt_geom_QuadCurve2D__241;
};

// Vtype
struct _jc_java_awt_geom_QuadCurve2D__241$vtype {
	_jc_type			type;
	_jc_java_awt_geom_QuadCurve2D__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_QuadCurve2D__241$sub_refs {
	struct _jc_java_awt_geom_QuadCurve2D$object	*this;
	struct _jc_java_awt_geom_AffineTransform$object	*val__24at;
};

// Reference instance fields (object)
struct _jc_java_awt_geom_QuadCurve2D__241$refs {
    _jc_java_awt_geom_QuadCurve2D__241$sub_refs	java_awt_geom_QuadCurve2D__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_QuadCurve2D__241$sub_nonrefs {
	jint	current;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_QuadCurve2D__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_QuadCurve2D__241$sub_nonrefs	java_awt_geom_QuadCurve2D__241;
};

// Object instance structure
struct _jc_java_awt_geom_QuadCurve2D__241$object {
	_jc_java_awt_geom_QuadCurve2D__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_QuadCurve2D__241$vtype	*vtype;
	_jc_java_awt_geom_QuadCurve2D__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_QuadCurve2D__241$vtype _jc_java_awt_geom_QuadCurve2D__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_QuadCurve2D__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_QuadCurve2D__241$class_object;

#endif	/* _JC_java_awt_geom_QuadCurve2D__241_H_ */
